/// <reference types="node" />
import * as fs from 'fs';
import { Architect, BuilderContext, Target } from '@angular-devkit/architect';
import { WorkspaceNodeModulesArchitectHost } from '@angular-devkit/architect/node';
import { WebpackLoggingCallback } from '@angular-devkit/build-webpack';
import { Path, experimental, logging, schema, virtualFs } from '@angular-devkit/core';
import webpack = require('webpack');
import { DevContainerAPI, DevContainerArgs, DevContainerConfig, DevContainerFactory, DevContainerRuntime } from '../../lib/devContainer';
import { BrowserBuilderSchema, ServerBuilderSchema } from './ng-devkit';
import { BuildUdkSchema } from './schema';
export declare type NgContainerAPI = DevContainerAPI;
export interface NgContainerConfig extends DevContainerConfig {
    angularProject?: string;
}
export interface NgContainerFactory extends DevContainerFactory {
    (proc: NodeJS.Process): NgContainerAPI;
}
export interface NgContainerArgs extends DevContainerArgs {
    project?: string;
    configuration?: string;
}
export declare const ANUGULAR_CONFIG_NAMES: string[];
export declare class NgContainer extends DevContainerRuntime {
    readonly runtimePath: string;
    readonly proc: NodeJS.Process;
    args: NgContainerArgs;
    firstCompilation: boolean;
    webpackLogging: WebpackLoggingCallback;
    angularConfigPath: string;
    architect: Architect;
    architectHost: WorkspaceNodeModulesArchitectHost;
    architectLogger: logging.LoggerApi;
    builderContext: BuilderContext;
    builderOptions: BuildUdkSchema;
    builderBrowserOptions: BuildUdkSchema;
    host: virtualFs.Host<fs.Stats>;
    registry: schema.SchemaRegistry;
    workspace: experimental.workspace.Workspace;
    browserIndexHtml: string | null;
    browserIndexSourcePath: Path;
    browserIndexOutputPath: Path;
    browserOptions: BrowserBuilderSchema;
    serverOptions: ServerBuilderSchema;
    constructor(runtimePath: string, proc: NodeJS.Process);
    bootstrap(): Promise<this>;
    getProjectTarget(args: NgContainerArgs, workspace: experimental.workspace.Workspace): Target;
    createArchitectLoggerAdapter(architectLogger: logging.LoggerApi): Console;
    getWebpackConfig(): Promise<webpack.Configuration[]>;
    onShutUp(config: DevContainerConfig): Promise<void>;
    printCompilerStats(_config: NgContainerConfig, multiStats: webpack.Stats): void;
    loadConfig(args: NgContainerArgs): {
        config: NgContainerConfig;
        configPath?: string | undefined;
    };
    parseProcessArgsOptions(): yargs.Options;
}
declare const _default: NgContainerFactory;
export default _default;
