/// <reference types="node" />
import * as fs from 'fs';
import { BuilderContext, BuilderOutput, Target } from '@angular-devkit/architect';
import { BrowserBuilderOptions, ExecutionTransformer } from '@angular-devkit/build-angular';
import { WebpackConfigOptions } from '@angular-devkit/build-angular/src/angular-cli-files/models/build-options';
import { Schema as BrowserBuilderSchema } from '@angular-devkit/build-angular/src/browser/schema';
import { Schema as ServerBuilderOptions } from '@angular-devkit/build-angular/src/server/schema';
import { WebpackLoggingCallback } from '@angular-devkit/build-webpack';
import { experimental, json, logging, virtualFs } from '@angular-devkit/core';
import { Observable } from 'rxjs';
import webpack = require('webpack');
import { BuildUdkSchema } from './schema';
export { WriteIndexHtmlOptions, writeIndexHtml, } from '@angular-devkit/build-angular/src/angular-cli-files/utilities/index-file/write-index-html';
export { readTsconfig, } from '@angular-devkit/build-angular/src/angular-cli-files/utilities/read-tsconfig';
export { augmentAppWithServiceWorker, } from '@angular-devkit/build-angular/src/angular-cli-files/utilities/service-worker';
export { FileReplacement, Schema as BrowserBuilderSchema, } from '@angular-devkit/build-angular/src/browser/schema';
export { Schema as ServerBuilderSchema } from '@angular-devkit/build-angular/src/server/schema';
export { BuildBrowserFeatures, } from '@angular-devkit/build-angular/src/utils/build-browser-features';
export { assertCompatibleAngularVersion } from '@angular-devkit/build-angular/src/utils/version';
export declare type UdkBuilderEmittedFile = json.JsonObject & {
    name?: string;
    file: string;
    initial: boolean;
    extension: string;
};
export declare type UdkBuilderOutput = BuilderOutput & {
    success: boolean;
    udkOptions: BuildUdkSchema;
    browserOptions: BrowserBuilderSchema;
    serverOptions: ServerBuilderOptions;
    browserES5EmittedFiles: UdkBuilderEmittedFile[];
    browserES6EmittedFiles: UdkBuilderEmittedFile[];
    browserFiles: UdkBuilderEmittedFile[];
    browserModuleFiles: UdkBuilderEmittedFile[];
    browserNoModuleFiles: UdkBuilderEmittedFile[];
    serverEmittedFiles: UdkBuilderEmittedFile[];
};
export declare type UdkPartialWebpackConfig = webpack.Configuration | webpack.Configuration[] | Observable<webpack.Configuration> | Promise<webpack.Configuration> | ExecutionTransformer<webpack.Configuration> | string | undefined;
export declare function adaptWebpackLoggingCallback(logFn: WebpackLoggingCallback): (multiStats: webpack.Stats | {
    stats: webpack.Stats[];
}, multiConfig: webpack.Configuration | webpack.Configuration[]) => void;
export declare function addWebpackConfigurationDependency(config: webpack.Configuration & {
    dependencies?: string[];
}, dependency: webpack.Configuration): void;
export declare function applyPartialWebpackConfig(context: BuilderContext, webpackConfig: webpack.Configuration, partialWebpackConfig$: UdkPartialWebpackConfig | UdkPartialWebpackConfig[]): Observable<webpack.Configuration>;
export declare function buildBrowserWebpackConfigs(options: BrowserBuilderSchema, context: BuilderContext, host: virtualFs.Host<fs.Stats>, supportDifferentialLoading: boolean): Promise<webpack.Configuration[]>;
export declare function buildServerWebpackConfig(udkOptions: BuildUdkSchema, serverOptions: ServerBuilderOptions, browserOptions: BrowserBuilderOptions, context: BuilderContext): Promise<webpack.Configuration>;
export declare function createLoggingCallback(logger: logging.LoggerApi, options?: {
    colors?: boolean;
    verbose?: boolean;
}): (multiStats: webpack.Stats | {
    stats: webpack.Stats[];
}, multiConfig: webpack.Configuration | webpack.Configuration[]) => void;
export declare function createUniversalBuilderOutput(udkOptions: json.JsonObject & BuildUdkSchema, browserOptions: json.JsonObject & BrowserBuilderSchema, serverOptions: json.JsonObject & ServerBuilderOptions, multiStats: webpack.Stats | {
    stats: webpack.Stats[];
}, multiConfig: webpack.Configuration | webpack.Configuration[]): UdkBuilderOutput;
export declare function isTerminalColorsEnabled(socket?: NodeJS.Socket): boolean;
export declare function isWebpackMultiStats(stats: webpack.Stats | {
    stats: webpack.Stats[];
}): boolean;
export declare function createWebpackUniversalConfig(serverConfig: webpack.Configuration, browserConfigs: webpack.Configuration | webpack.Configuration[]): webpack.Configuration[];
export declare function deleteConfigOutputPath(root: string, host: virtualFs.Host<fs.Stats>, config: webpack.Configuration): Promise<void | null>;
export declare function getCompilerConfig(wco: WebpackConfigOptions): webpack.Configuration;
export declare function getProjectName(context: BuilderContext, workspace: experimental.workspace.Workspace): string | null;
export declare function makeTargetSpecifier(targetSpecString: string, defaultSpec?: Target): Target;
export declare function setWebpackFileLoaderEmitFile(udkOptions: BuildUdkSchema, serverOptions: ServerBuilderOptions, browserOptions: BrowserBuilderOptions, webpackConfig: webpack.Configuration): void;
